@@ -85,6 +85,8 @@ class LinkPlayCommand(StrEnum):
     STOP = "setPlayerCmd:stop"
     TOGGLE = "setPlayerCmd:onepause"
     EQUALIZER_MODE = "setPlayerCmd:equalizer:{}"
+    WIIM_EQUALIZER_ON = "EQOn"
+    WIIM_EQUALIZER_OFF = "EQOff"
     LOOP_MODE = "setPlayerCmd:loopmode:{}"
     SWITCH_MODE = "setPlayerCmd:switchmode:{}"
     M3U_PLAYLIST = "setPlayerCmd:m3u:play:{}"
@@ -97,6 +99,7 @@ class LinkPlayCommand(StrEnum):
     MULTIROOM_JOIN = "ConnectMasterAp:JoinGroupMaster:eth{}:wifi0.0.0.0"
     PLAY_PRESET = "MCUKeyShortClick:{}"
     TIMESYNC = "timeSync:{}"
+    WIIM_EQ_LOAD = "EQLoad:{}"
 
 
 class LinkPlayTcpUartCommand(StrEnum):
@@ -219,11 +222,33 @@ class LoopMode(StrEnum):
 class EqualizerMode(StrEnum):
     """Defines the equalizer mode."""
 
-    NONE = "0"
-    CLASSIC = "1"
-    POP = "2"
-    JAZZ = "3"
-    VOCAL = "4"
+    NONE = "None"
+    CLASSIC = "Classic"
+    POP = "Pop"
+    JAZZ = "Jazz"
+    VOCAL = "Vocal"
+
+    # Custom equalizer modes specificly for WiiM devices
+    FLAT = "Flat"
+    ACOUSTIC = "Acoustic"
+    BASS_BOOSTER = "Bass Booster"
+    BASS_REDUCER = "Bass Reducer"
+    CLASSICAL = "Classical"
+    DANCE = "Dance"
+    DEEP = "Deep"
+    ELECTRONIC = "Electronic"
+    HIP_HOP = "Hip-Hop"
+    LATIN = "Latin"
+    LOUDNESS = "Loudness"
+    LOUNGE = "Lounge"
+    PIANO = "Piano"
+    R_B = "R&B"
+    ROCK = "Rock"
+    SMALL_SPEAKERS = "Small Speakers"
+    SPOKEN_WORD = "Spoken Word"
+    TREBLE_BOOSTER = "Treble Booster"
+    TREBLE_REDUCER = "Treble Reducer"
+    VOCAL_BOOSTER = "Vocal Booster"
 
 
 class PlayingStatus(StrEnum):
